@@ -17,7 +17,7 @@ class UpdatePayoutAccount:
 
         id = ""
         if "id" in json_data:
-            id = json_data["dataEndpoints"]
+            id = json_data["id"]
         else:
             return {
                 "code": 400,
